import { EndpointGetFunction } from "request-registry";
declare type EndpointKeys<TEndpointGetFunction> = TEndpointGetFunction extends EndpointGetFunction<infer TKeys, any> ? TKeys : never;
declare type EndpointResult<TEndpointGetFunction> = TEndpointGetFunction extends EndpointGetFunction<any, infer TResult> ? TResult : never;
/**
 * Get the data from the given endpoint and caches the result as long as the component is mounted
 *
 * The keys object has to be passed only if it contains a value
 */
export declare function useGetEndPoint<TEndpoint extends EndpointGetFunction<{
    [key: string]: never | undefined;
}, any>>(endpoint: TEndpoint): EndpointState<EndpointResult<TEndpoint>>;
export declare function useGetEndPoint<TEndpoint extends EndpointGetFunction<any, any>>(endpoint: TEndpoint, keys: EndpointKeys<TEndpoint>, executeAjax?: boolean, catchErrors?: boolean): EndpointState<EndpointResult<TEndpoint>>;
/**
 * Provide a hook which works with React.Suspense
 */
export declare function useGetEndPointSuspendable<TKeys extends EndpointKeys<TEndpoint>, TResult extends EndpointResult<TEndpoint>, TEndpoint extends EndpointGetFunction<any, any>>(endpoint: TEndpoint, keys: TKeys): TResult;
/**
 * Get the data from the given endpoint and caches the result as long as the component is mounted
 *
 * Will be executed only client side in the Browser
 *
 * The keys object has to be passed only if it contains a value
 */
export declare function useGetEndPointLazy<TEndpoint extends EndpointGetFunction<{
    [key: string]: never | undefined;
}, any>>(endpoint: TEndpoint): EndpointState<EndpointResult<TEndpoint>>;
export declare function useGetEndPointLazy<TEndpoint extends EndpointGetFunction<any, any>>(endpoint: TEndpoint, keys: EndpointKeys<TEndpoint>, executeAjax?: boolean): EndpointState<EndpointResult<TEndpoint>>;
declare type EndpointState<TResult> = {
    busy: true;
    value: undefined;
    state: "LOADING";
    hasData: false;
    error: undefined;
    promise: Promise<TResult>;
} | {
    busy: false;
    value: undefined;
    state: "ERROR";
    hasData: false;
    error: unknown;
    promise: Promise<TResult>;
} | {
    busy: true;
    value: TResult;
    state: "UPDATING";
    hasData: true;
    error: undefined;
    promise: Promise<TResult>;
} | {
    busy: false;
    value: TResult;
    state: "DONE";
    hasData: true;
    error: undefined;
    promise: Promise<TResult>;
};
export {};
